#imports (barebones 1.2)
import requests
import random

# logic (updated)
def generate(length=None, noNum=None):
    if length is None or not isinstance(length, int):
        length = 7
    url = f'https://random-word-api.herokuapp.com/word?length={length}'
    resp = requests.get(url=url)
    resp2 = requests.get(url=url)
    data = [word.capitalize() for word in (resp.json() + resp2.json())]
    randomnum = random.randint(127, 999)
    if noNum is None or noNum is False:
        final = ''.join(data) + str(randomnum)
    elif noNum is True:
        final = ''.join(data)
    
    return final



from setuptools import setup, find_packages
import sys

requirements = [
    'requests',
]

if sys.platform != 'win32':
    requirements.append('some-unix-only-package')

setup(
    name='ezusergen',
    version='0.1.3',
    description='A simple username generator that combines random words with numbers',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author='Ondry',
    author_email='ondrygfx@gmail.com',
    url='https://github.com/Ondry4K/ezusergen',
    packages=find_packages(),
    install_requires=[
        'requests',
    ],
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
)
